@@ -1,7 +1,6 @@
 import argparse
 
-
-__version__ = '0.7.0'
+__version__ = '0.9.0'
 
 
 class Integer:
@@ -30,3 +29,31 @@ class Integer:
 
     def __repr__(self):
         return 'integer'
+
+
+def parse_log_level(value):
+    """Parse given set log level value.
+
+    Examples:
+
+    <logger-name>=<level>
+
+    <logger-1-name>=<level-1>;<logger-2-name>=<level-2>
+
+    <logger-1-name>,<logger-2-name>=<level>
+
+    """
+
+    result = []
+
+    for part in value.split(';'):
+        if '=' in part:
+            names, level = part.split('=')
+
+            for name in names.split(','):
+                result.append((name, level))
+        else:
+            # None for root logger.
+            result.append((None, part))
+
+    return result
